projectal.entities.access_policy API documentation

# projectal.entities.access_policy

View Source

    from projectal.entity import Entity
    from projectal.linkers import PermissionLinker

    class AccessPolicy(Entity, PermissionLinker):
        """
        Implementation of the [Access Policy](https://projectal.com/docs/latest/#tag/Access-Policy) API.
        """
        _path = 'access-policy'
        _name = 'ACCESS_POLICY'

class AccessPolicy(projectal.entity.Entity, projectal.linkers.PermissionLinker):
View Source

    class AccessPolicy(Entity, PermissionLinker):
        """
        Implementation of the [Access Policy](https://projectal.com/docs/latest/#tag/Access-Policy) API.
        """
        _path = 'access-policy'
        _name = 'ACCESS_POLICY'

Implementation of the Access Policy API.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  create
  save
  clone
  history
  list
  match
  match_startswith
  match_endswith
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
projectal.linkers.PermissionLinker
  link_permission
  unlink_permission
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy